<template>
  <div class="bar-chart">
    <ChartTitle name="物料需求统计"></ChartTitle>
    <div class="bar-contents">
      <div class="chart" ref="chart"></div>
    </div>
  </div>
</template>

<script>
import ChartTitle from "@/views/cockpitPage/components/ChartTitle.vue";
//引入echart
import * as echarts from "echarts";
let myChart;
export default {
  components: {
    ChartTitle,
  },
  props: {
    chartData: {
      type: Object,
      require: true,
      default: () => {
        return {
          datax: [],
          datay: [],
        };
      },
    },
  },
  data() {
    return {
      startValue: 0,
      endValue: 5,
      chartTimer: null,
    };
  },
  watch: {
    "chartData.datay"(val) {
      this.startValue = 0;
      this.endValue = 5;
      this.pieChart("chart", this.chartData);
    },
  },
  mounted() {},
  methods: {
    //在职
    pieChart(chartName, data) {
      let that = this;
      clearInterval(this.chartTimer);
      let chartDom = this.$refs[chartName];
      if (myChart != null && myChart != "" && myChart != undefined) {
        myChart.dispose(); //销毁
      }
      myChart = echarts.init(chartDom);
      let option;
      let lineColor = "#35ddc74d";
      if (data) {
        option = {
          color: ["#00FFFF", "#dcb018"],
          tooltip: {
            trigger: "axis",
            axisPointer: {
              type: "none",
            },
          },
          grid: {
            right: "80px",
            bottom: "60px",
            left: "70px",
            top: "30px",
          },
          dataZoom: [
            {
              type: "inside",
              yAxisIndex: 0,
              show: false,
              startValue: that.startValue, // 从头开始
              endValue: that.endValue, // 一次性展示几个
              zoomOnMouseWheel: false,
              moveOnMouseWheel: true,
              moveOnMouseMove: true,
            },
          ],
          legend: {
            itemWidth: 8,
            itemHeight: 8,
            itemGap: 35, //间距
            bottom: "5px",
            left: "center",
          },
          yAxis: [
            {
              type: "category",
              axisTick: {
                show: false,
              },
              axisLine: {
                show: true,
                lineStyle: {
                  color: lineColor,
                },
              },
              axisLabel: {
                // rotate:45,
                margin: 10,
                show: true,
                fontSize: 12,
                textStyle: {
                  color: function (params, index) {
                    let colorList = ["#dcb018", "#00FFFF"];
                    if (index % 2 == 0) {
                      return colorList[0];
                    } else {
                      return colorList[1];
                    }
                  },
                },
                formatter: function (value) {
                  if (value.length > 5) {
                    return `${value.slice(0, 4)}...`;
                  }
                  return value;
                },
              },
              data: data.datax ? data.datax : [],
            },
          ],
          xAxis: [
            {
              type: "value",
              name: "单位：件",
              // min: data.yAxis[0].min?data.yAxis.min:0,
              minInterval: 1, //坐标轴是整数
              max: Math.ceil(eval(`Math.max(${data.datay})`) / 5) * 5, //数据最大值加3
              interval:
                (Math.ceil(eval(`Math.max(${data.datay})`) / 7) * 7) / 7,
              position: "left",
              axisLine: {
                show: true,
                lineStyle: {
                  color: "#0a112B",
                },
              },
              nameTextStyle: {
                color: "#00FFFF",
              },
              splitLine: {
                show: true,
                lineStyle: {
                  // 使用深浅的间隔色
                  color: lineColor,
                },
              },
              axisTick: {
                show: false,
              },

              axisLabel: {
                textStyle: {
                  color: "#00FFFF",
                },
                formatter: function (value) {
                  return `${(value / 1000).toFixed(1)}k`;
                },
              },
            },
          ],
          series: [
            {
              type: "bar",
              name: "",
              barWidth: "15",
              itemStyle: {
                normal: {
                  //柱形图圆角，初始化效果
                  barBorderRadius: [4, 4, 0, 0],
                  color: function (params) {
                    let colorList = ["#dcb018", "#00FFFF"];
                    if (params.dataIndex % 2 == 0) {
                      return colorList[0];
                    } else {
                      return colorList[1];
                    }
                  },
                },
              },
              data: data.datay,
            },
          ],
        };
        this.chartTimer = setInterval(function () {
          if (option.dataZoom[0].endValue == that.chartData.datay.length) {
            option.dataZoom[0].startValue = 0;
            option.dataZoom[0].endValue = 5;
          } else {
            option.dataZoom[0].endValue = option.dataZoom[0].endValue + 1;
            option.dataZoom[0].startValue = option.dataZoom[0].startValue + 1;
          }
          myChart.setOption(option);
        }, 4000);

        option && myChart.setOption(option);
        window.addEventListener("resize", function () {
          myChart.resize();
        });
      } else {
        option = {};
        myChart.setOption(option, true);
      }
    },
  },
};
</script>

<style scoped lang="scss">
.bar-chart {
  width: 100%;
  height: calc(100% - 20px);
  padding: 20px 0 0;
  .bar-contents {
    width: 100%;
    height: calc(100% - 60px);
    border: 1px solid #00ffff;
    box-sizing: border-box;
    .chart {
      width: 100%;
      height: 100%;
    }
  }
}
</style>
